Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(232)

Unified Diff: src/gpu/glsl/GrGLSLXferProcessor.h

Issue 1440073002: Move XferProcessors to glsl (Closed) Base URL: https://skia.googlesource.com/skia.git@fragProcs
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/gl/builders/GrGLProgramBuilder.cpp ('k') | src/gpu/glsl/GrGLSLXferProcessor.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/glsl/GrGLSLXferProcessor.h
diff --git a/src/gpu/gl/GrGLXferProcessor.h b/src/gpu/glsl/GrGLSLXferProcessor.h
similarity index 86%
rename from src/gpu/gl/GrGLXferProcessor.h
rename to src/gpu/glsl/GrGLSLXferProcessor.h
index 1e505f3d07b8c295806e85456cc42e982229aeb0..79f59b8627a404bac036e9a5fe9753cf47aedd54 100644
--- a/src/gpu/gl/GrGLXferProcessor.h
+++ b/src/gpu/glsl/GrGLSLXferProcessor.h
@@ -1,12 +1,12 @@
/*
- * Copyright 2014 Google Inc.
+ * Copyright 2015 Google Inc.
*
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef GrGLXferProcessor_DEFINED
-#define GrGLXferProcessor_DEFINED
+#ifndef GrGLSLXferProcessor_DEFINED
+#define GrGLSLXferProcessor_DEFINED
#include "glsl/GrGLSLProgramDataManager.h"
#include "glsl/GrGLSLTextureSampler.h"
@@ -14,10 +14,10 @@
class GrGLSLXPBuilder;
class GrXferProcessor;
-class GrGLXferProcessor {
+class GrGLSLXferProcessor {
public:
- GrGLXferProcessor() {}
- virtual ~GrGLXferProcessor() {}
+ GrGLSLXferProcessor() {}
+ virtual ~GrGLSLXferProcessor() {}
typedef GrGLSLTextureSampler::TextureSamplerArray TextureSamplerArray;
struct EmitArgs {
@@ -50,12 +50,12 @@ public:
*/
void emitCode(const EmitArgs&);
- /** A GrGLXferProcessor instance can be reused with any GrGLXferProcessor that produces
- the same stage key; this function reads data from a GrGLXferProcessor and uploads any
+ /** A GrGLSLXferProcessor instance can be reused with any GrGLSLXferProcessor that produces
+ the same stage key; this function reads data from a GrGLSLXferProcessor and uploads any
uniform variables required by the shaders created in emitCode(). The GrXferProcessor
- parameter is guaranteed to be of the same type that created this GrGLXferProcessor and
- to have an identical processor key as the one that created this GrGLXferProcessor. This
- function calls onSetData on the subclass of GrGLXferProcessor
+ parameter is guaranteed to be of the same type that created this GrGLSLXferProcessor and
+ to have an identical processor key as the one that created this GrGLSLXferProcessor. This
+ function calls onSetData on the subclass of GrGLSLXferProcessor
*/
void setData(const GrGLSLProgramDataManager& pdm, const GrXferProcessor& xp);
« no previous file with comments | « src/gpu/gl/builders/GrGLProgramBuilder.cpp ('k') | src/gpu/glsl/GrGLSLXferProcessor.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698